@@ -279,6 +279,17 @@ class OpenEuler():
             log.error(f"get rpm list from repo {repo_url} failed, error message is {str(e)}")
             return []
 
+    def get_src_name(self,os_version,os_arch,rpm_name):
+        everything_data=self.get_openEuler_everything_rpm2src(os_version,os_arch)
+        if rpm_name in everything_data.keys():
+            return everything_data[rpm_name]
+        epol_data=self.get_openEuler_epol_rpm2src(os_version,os_arch)
+        if rpm_name in epol_data.keys():
+            return epol_data[rpm_name]
+        return rpm_name
+
+
+
     def get_openEuler_everything_rpm_list(self, os_version: str, os_arch: str):
         url=f"https://fast-mirror.isrc.ac.cn/openeuler/openEuler-{os_version}/everything/{os_arch}"
         return self.get_rpm_list(url)
@@ -470,9 +481,23 @@ if __name__ == "__main__":
     # rs = oe.get_openEuler_everything_rpm2src("24.03-LTS-SP2", "x86_64")
     # print(len(rs.keys()))
 
-    oe = OpenEuler()
-    rs = oe.get_openEuler_epol_rpm2src("24.03-LTS-SP2", "x86_64")
-    print(len(rs.keys()))
+    # oe = OpenEuler()
+    # rs = oe.get_openEuler_epol_rpm2src("24.03-LTS-SP2", "x86_64")
+    # print(len(rs.keys()))
+
+    # oe=OpenEuler()
+    # src_name=oe.get_src_name("24.03-LTS-SP2", "x86_64", "acl-help")
+    # print(src_name)
+
+    # oe=OpenEuler()
+    # rs=oe.get_rpm_list("https://diamond.oerv.ac.cn/openruyi/riscv64")
+    # rs2=oe.get_openEuler_all_rpm_list("24.03-LTS-SP2", "x86_64")
+    # rs3=[]
+    # for elem in rs:
+    #     if elem in rs2:
+    #         rs3.append(elem)
+    # print(f"total {len(rs)} rpms and {len(rs3)} same with x86_64")
+
 
     pass
 
